@@ -500,8 +500,8 @@ def get_time_to_fix(bug):
         return None
 
     return (
-        dateutil.parser.parse(bug["cf_last_resolved"]).replace(tzinfo=None)
-        - dateutil.parser.parse(bug["creation_time"]).replace(tzinfo=None)
+        dateutil.parser.parse(bug["cf_last_resolved"])
+        - dateutil.parser.parse(bug["creation_time"])
     ).total_seconds() / 86400
 
 
@@ -519,8 +519,8 @@ def get_time_to_assign(bug):
                 and change["added"] == "ASSIGNED"
             ):
                 return (
-                    dateutil.parser.parse(history["when"]).replace(tzinfo=None)
-                    - dateutil.parser.parse(bug["creation_time"]).replace(tzinfo=None)
+                    dateutil.parser.parse(history["when"])
+                    - dateutil.parser.parse(bug["creation_time"])
                 ).total_seconds() / 86400
 
     return None
