@@ -23,7 +23,8 @@ from sklearn.metrics import precision_recall_fscore_support
 from sklearn.model_selection import cross_validate, train_test_split
 from tabulate import tabulate
 
-from bugbug import bugzilla, db, github, repository
+from bugbug import bugzilla, db, repository
+from bugbug.github import Github
 from bugbug.nlp import SpacyVectorizer
 from bugbug.utils import split_tuple_generator, to_array
 
@@ -754,12 +755,14 @@ class BugCoupleModel(Model):
 
 
 class IssueModel(Model):
-    def __init__(self, lemmatization=False):
+    def __init__(self, owner, repo, lemmatization=False):
         Model.__init__(self, lemmatization)
-        self.training_dbs = [github.GITHUB_ISSUES_DB]
+
+        self.github = Github(owner=owner, repo=repo)
+        self.training_dbs = [self.github.db_path]
 
     def items_gen(self, classes):
-        for issue in github.get_issues():
+        for issue in self.github.get_issues():
             issue_number = issue["number"]
             if issue_number not in classes:
                 continue
