@@ -119,22 +119,10 @@ class DefectModel(BugModel):
                 if category != "nobug":
                     classes[int(bug_id)] = "defect"
 
-        defect_enhancement_task_e = {
-            bug_id: category
-            for bug_id, category in labels.get_labels("defect_enhancement_task_e")
-        }
-        defect_enhancement_task_p = {
-            bug_id: category
-            for bug_id, category in labels.get_labels("defect_enhancement_task_p")
-        }
-        defect_enhancement_task_s = {
-            bug_id: category
-            for bug_id, category in labels.get_labels("defect_enhancement_task_s")
-        }
-        defect_enhancement_task_h = {
-            bug_id: category
-            for bug_id, category in labels.get_labels("defect_enhancement_task_h")
-        }
+        defect_enhancement_task_e = dict(labels.get_labels("defect_enhancement_task_e"))
+        defect_enhancement_task_p = dict(labels.get_labels("defect_enhancement_task_p"))
+        defect_enhancement_task_s = dict(labels.get_labels("defect_enhancement_task_s"))
+        defect_enhancement_task_h = dict(labels.get_labels("defect_enhancement_task_h"))
 
         defect_enhancement_task_common = (
             (bug_id, category)
@@ -179,12 +167,16 @@ class DefectModel(BugModel):
             if bug_id in classes:
                 continue
 
-            if any(
-                keyword in bug["keywords"]
-                for keyword in ["regression", "talos-regression"]
-            ) or (
-                "cf_has_regression_range" in bug
-                and bug["cf_has_regression_range"] == "yes"
+            if (
+                len(bug["regressed_by"]) > 0
+                or any(
+                    keyword in bug["keywords"]
+                    for keyword in ["regression", "talos-regression"]
+                )
+                or (
+                    "cf_has_regression_range" in bug
+                    and bug["cf_has_regression_range"] == "yes"
+                )
             ):
                 if kind in ["bug", "regression"]:
                     classes[bug_id] = 1
@@ -218,11 +210,16 @@ class DefectModel(BugModel):
 
             # And we can use the type as a label for bugs whose type has been modified.
             # For 'defects', we can't use them as labels unless resulting from a change, because bugs are filed by default as 'defect' and so they could be mistakes.
-            if not can_use_type or bug["type"] == "defect":
+            def _has_type_changed(bug):
                 for history in bug["history"]:
                     for change in history["changes"]:
                         if change["field_name"] == "type":
-                            can_use_type = can_use_defect_type = True
+                            return True
+
+                return False
+
+            if not can_use_type or bug["type"] == "defect":
+                can_use_type = can_use_defect_type = _has_type_changed(bug)
 
             if can_use_type:
                 if bug["type"] == "enhancement":
