@@ -13,7 +13,7 @@ class RegressionModel(DefectModel):
         DefectModel.__init__(self, lemmatization, historical)
         self.calculate_importance = False
 
-    def get_labels(self) -> Tuple[Dict[int, Any], List[Any]]:
+    def get_labels(self) -> Tuple[Dict[int, Any], List[int]]:
         classes = self.get_bugbug_labels("regression")
 
         print(
