@@ -7,6 +7,7 @@ import logging
 from datetime import datetime, timedelta
 from typing import Collection, Iterator, NewType, Optional
 
+import tenacity
 from libmozdata.phabricator import PhabricatorAPI
 from tqdm import tqdm
 
@@ -51,9 +52,14 @@ def get_transactions(rev_phid: str) -> Collection[TransactionDict]:
     data = []
 
     while after is not None:
-        out = PHABRICATOR_API.request(
-            "transaction.search", objectIdentifier=rev_phid, limit=1000, after=after
-        )
+        out = tenacity.retry(
+            wait=tenacity.wait_exponential(multiplier=1, min=4, max=64),
+            stop=tenacity.stop_after_attempt(5),
+        )(
+            lambda PHABRICATOR_API=PHABRICATOR_API: PHABRICATOR_API.request(
+                "transaction.search", objectIdentifier=rev_phid, limit=1000, after=after
+            )
+        )()
         data += out["data"]
         after = out["cursor"]["after"]
 
@@ -69,26 +75,45 @@ def get(
     constraints: dict = {}
     if rev_ids is not None:
         constraints["ids"] = rev_ids
+        progress_bar = None
     elif modified_start is not None:
         constraints["modifiedStart"] = int(modified_start.timestamp())
+        progress_bar = tqdm()
 
     after = ""
     data = []
 
     while after is not None:
-        out = PHABRICATOR_API.request(
-            "differential.revision.search",
-            constraints=constraints,
-            attachments={"projects": True, "reviewers": True},
-            after=after,
-        )
+        out = tenacity.retry(
+            wait=tenacity.wait_exponential(multiplier=1, min=4, max=64),
+            stop=tenacity.stop_after_attempt(5),
+        )(
+            lambda PHABRICATOR_API=PHABRICATOR_API: PHABRICATOR_API.request(
+                "differential.revision.search",
+                constraints=constraints,
+                attachments={"projects": True, "reviewers": True},
+                after=after,
+            )
+        )()
         data += out["data"]
         after = out["cursor"]["after"]
 
-    for revision in data:
+        if progress_bar is not None:
+            progress_bar.update(100)
+
+    if progress_bar is not None:
+        progress_bar.close()
+        data_iter = tqdm(data)
+    else:
+        data_iter = data
+
+    for revision in data_iter:
         assert "transactions" not in revision
         revision["transactions"] = get_transactions(revision["phid"])
 
+    if progress_bar is not None:
+        data_iter.close()
+
     return data
 
 
