@@ -12,6 +12,7 @@ import re
 import shelve
 import shutil
 import struct
+from datetime import datetime
 from typing import (
     Any,
     Callable,
@@ -29,6 +30,7 @@ from typing import (
     cast,
 )
 
+import requests
 from tqdm import tqdm
 
 from bugbug import db, repository
@@ -595,7 +597,7 @@ def update_touched_together() -> Generator[None, Optional[Revision], None]:
     )
 
     # We can start once we get to the last revision we added in the previous run.
-    can_start = True if last_analyzed is None else False
+    can_start = last_analyzed is None
 
     seen = set()
 
@@ -812,3 +814,24 @@ def generate_data(
             obj["touched_together_directories"] = touched_together_directories
 
         yield obj
+
+
+def get_failure_bugs(since: datetime, until: datetime) -> List[Dict[str, int]]:
+    r = requests.get(
+        "https://treeherder.mozilla.org/api/failures/?startday={}&endday={}&tree=trunk".format(
+            since.strftime("%Y-%m-%d"), until.strftime("%Y-%m-%d")
+        ),
+        headers={"Accept": "application/json", "User-Agent": "bugbug"},
+    )
+    r.raise_for_status()
+    return r.json()
+
+
+def get_test_info(date: datetime) -> Dict[str, Any]:
+    r = requests.get(
+        "https://firefox-ci-tc.services.mozilla.com/api/index/v1/task/gecko.v2.mozilla-central.pushdate.{}.latest.source.test-info-all/artifacts/public/test-info-all-tests.json".format(
+            date.strftime("%Y.%m.%d")
+        )
+    )
+    r.raise_for_status()
+    return r.json()
