@@ -21,7 +21,7 @@ from libmozdata import vcs_map
 from microannotate import utils as microannotate_utils
 from tqdm import tqdm
 
-from bugbug import bugzilla, db, repository
+from bugbug import bugzilla, db, labels, repository
 from bugbug.models.defect_enhancement_task import DefectEnhancementTaskModel
 from bugbug.models.regression import RegressionModel
 from bugbug.models.regressor import (
@@ -37,7 +37,7 @@ logger = getLogger(__name__)
 thread_local = threading.local()
 
 MAX_MODIFICATION_NUMBER = 50
-RELATIVE_START_DATE = relativedelta(years=2, months=6)
+RELATIVE_START_DATE = relativedelta(years=2)
 # Only needed because mercurial<->git mapping could be behind.
 RELATIVE_END_DATE = relativedelta(days=7)
 
@@ -125,6 +125,10 @@ class RegressorFinder(object):
         commits_to_ignore = []
         all_commits = set()
 
+        annotate_ignore_nodes = {
+            node for node, label in labels.get_labels("annotateignore") if label == "1"
+        }
+
         for commit in repository.get_commits(
             include_no_bug=True, include_backouts=True, include_ignored=True
         ):
@@ -136,6 +140,7 @@ class RegressorFinder(object):
                 or not commit["bug_id"]
                 or len(commit["backsout"]) > 0
                 or repository.is_wptsync(commit)
+                or commit["node"] in annotate_ignore_nodes
             ):
                 commits_to_ignore.append(
                     {
@@ -237,6 +242,7 @@ class RegressorFinder(object):
         known_regression_labels, _ = regression_model.get_labels()
 
         bug_fixing_commits = []
+        bugs_to_classify = []
 
         def append_bug_fixing_commits(bug_id: int, type_: str) -> None:
             for commit in commit_map[bug_id]:
@@ -262,14 +268,30 @@ class RegressorFinder(object):
                     append_bug_fixing_commits(bug["id"], "e")
                 continue
 
-            if defect_model.classify(bug)[0] == "defect":
-                if regression_model.classify(bug)[0] == 1:
-                    append_bug_fixing_commits(bug["id"], "r")
-                else:
-                    append_bug_fixing_commits(bug["id"], "d")
+            bugs_to_classify.append(bug)
+
+        classified_bugs = []
+        if bugs_to_classify:
+            classified_bugs = defect_model.classify(bugs_to_classify)
+
+        defect_bugs = []
+
+        for bug, label in zip(bugs_to_classify, classified_bugs):
+            if label == "defect":
+                defect_bugs.append(bug)
             else:
                 append_bug_fixing_commits(bug["id"], "e")
 
+        classified_defect_bugs = []
+        if defect_bugs:
+            classified_defect_bugs = regression_model.classify(defect_bugs)
+
+        for bug, classification in zip(defect_bugs, classified_defect_bugs):
+            if classification == 1:
+                append_bug_fixing_commits(bug["id"], "r")
+            else:
+                append_bug_fixing_commits(bug["id"], "d")
+
         db.append(BUG_FIXING_COMMITS_DB, bug_fixing_commits)
         zstd_compress(BUG_FIXING_COMMITS_DB)
         db.upload(BUG_FIXING_COMMITS_DB)
